@@ -4,14 +4,12 @@ import math
 import numpy as np
 from numpy.typing import NDArray
 
-from libecalc.common.energy_model_type import EnergyModelType
 from libecalc.common.errors.exceptions import IllegalStateException
 from libecalc.common.logger import logger
 from libecalc.common.units import UnitConstants
 from libecalc.domain.component_validation_error import ProcessPressureRatioValidationException
 from libecalc.domain.process.compressor.core.results import (
     CompressorTrainResultSingleTimeStep,
-    CompressorTrainStageResultSingleTimeStep,
 )
 from libecalc.domain.process.compressor.core.train.base import CompressorTrainModel
 from libecalc.domain.process.compressor.core.train.stage import CompressorTrainStage, UndefinedCompressorStage
@@ -20,12 +18,9 @@ from libecalc.domain.process.compressor.core.train.utils.enthalpy_calculations i
     calculate_enthalpy_change_head_iteration,
     calculate_polytropic_head_campbell,
 )
-from libecalc.domain.process.compressor.core.utils import map_compressor_train_stage_to_domain
-from libecalc.domain.process.compressor.dto import CompressorStage
-from libecalc.domain.process.value_objects.chart.chart_area_flag import ChartAreaFlag
-from libecalc.domain.process.value_objects.chart.compressor import VariableSpeedCompressorChart
+from libecalc.domain.process.value_objects.chart.compressor import CompressorChart
 from libecalc.domain.process.value_objects.chart.compressor.chart_creator import CompressorChartCreator
-from libecalc.domain.process.value_objects.fluid_stream import FluidStream, ProcessConditions
+from libecalc.domain.process.value_objects.fluid_stream import FluidStream
 from libecalc.domain.process.value_objects.fluid_stream.fluid_factory import FluidFactoryInterface
 
 
@@ -170,10 +165,9 @@ class CompressorTrainSimplified(CompressorTrainModel, abc.ABC):
         if inlet_stream.mass_rate_kg_per_h > 0:
             compressor_stages_result = []
             for stage in self.stages:
-                compressor_stage_result = self.calculate_compressor_stage_work_given_outlet_pressure(
+                compressor_stage_result = stage.evaluate_given_target_pressure_ratio(
                     inlet_stream=inlet_stream,
-                    pressure_ratio=pressure_ratios_per_stage,  # type: ignore[arg-type]
-                    stage=stage,
+                    target_pressure_ratio=pressure_ratios_per_stage,  # type: ignore[arg-type]
                 )
 
                 compressor_stages_result.append(compressor_stage_result)
@@ -193,127 +187,6 @@ class CompressorTrainSimplified(CompressorTrainModel, abc.ABC):
         else:
             return CompressorTrainResultSingleTimeStep.create_empty(number_of_stages=len(self.stages))
 
-    def calculate_compressor_stage_work_given_outlet_pressure(
-        self,
-        inlet_stream: FluidStream,
-        pressure_ratio: float,
-        stage: CompressorTrainStage,
-        adjust_for_chart: bool = True,
-    ) -> CompressorTrainStageResultSingleTimeStep:
-        outlet_pressure = inlet_stream.pressure_bara * pressure_ratio
-
-        inlet_stream = inlet_stream.create_stream_with_new_conditions(
-            conditions=ProcessConditions(
-                pressure_bara=inlet_stream.pressure_bara,
-                temperature_kelvin=stage.inlet_temperature_kelvin,
-            )
-        )
-
-        # To avoid passing empty arrays down to the enthalpy calculation.
-        if inlet_stream.mass_rate_kg_per_h > 0:
-            polytropic_enthalpy_change_joule_per_kg, polytropic_efficiency = calculate_enthalpy_change_head_iteration(
-                inlet_streams=inlet_stream,
-                outlet_pressure=outlet_pressure,
-                polytropic_efficiency_vs_rate_and_head_function=stage.compressor_chart.efficiency_as_function_of_rate_and_head,
-            )
-
-            # Chart corrections to rate and head
-            if adjust_for_chart:
-                head_joule_per_kg = polytropic_enthalpy_change_joule_per_kg * polytropic_efficiency
-                compressor_chart_result = stage.compressor_chart.evaluate_capacity_and_extrapolate_below_minimum(
-                    actual_volume_rates=inlet_stream.volumetric_rate,
-                    heads=head_joule_per_kg,
-                    extrapolate_heads_below_minimum=True,
-                )
-                asv_corrected_actual_rate_m3_per_hour = compressor_chart_result.asv_corrected_rates[0]
-                choke_corrected_polytropic_head = compressor_chart_result.choke_corrected_heads[0]
-                rate_has_recirc = compressor_chart_result.rate_has_recirc[0]
-                pressure_is_choked = compressor_chart_result.pressure_is_choked[0]
-                rate_exceeds_maximum = compressor_chart_result.rate_exceeds_maximum[0]
-                head_exceeds_maximum = compressor_chart_result.head_exceeds_maximum[0]
-                exceeds_capacity = compressor_chart_result.exceeds_capacity[0]
-
-                polytropic_enthalpy_change_to_use_joule_per_kg = choke_corrected_polytropic_head / polytropic_efficiency
-                mass_rate_to_use_kg_per_hour = asv_corrected_actual_rate_m3_per_hour * inlet_stream.density
-            else:
-                polytropic_enthalpy_change_to_use_joule_per_kg = polytropic_enthalpy_change_joule_per_kg
-                asv_corrected_actual_rate_m3_per_hour = inlet_stream.volumetric_rate
-                mass_rate_to_use_kg_per_hour = inlet_stream.mass_rate_kg_per_h
-                rate_has_recirc = False
-                pressure_is_choked = False
-                rate_exceeds_maximum = False
-                head_exceeds_maximum = False
-                exceeds_capacity = False
-
-        else:
-            polytropic_enthalpy_change_to_use_joule_per_kg = 0.0
-            polytropic_enthalpy_change_joule_per_kg = 0.0
-            polytropic_efficiency = np.nan
-            asv_corrected_actual_rate_m3_per_hour = inlet_stream.volumetric_rate
-            mass_rate_to_use_kg_per_hour = inlet_stream.mass_rate_kg_per_h
-            rate_has_recirc = False
-            pressure_is_choked = False
-            rate_exceeds_maximum = False
-            head_exceeds_maximum = False
-            exceeds_capacity = False
-
-        outlet_stream = inlet_stream.create_stream_with_new_pressure_and_enthalpy_change(
-            pressure_bara=outlet_pressure,
-            enthalpy_change_joule_per_kg=polytropic_enthalpy_change_to_use_joule_per_kg,  # type: ignore[arg-type]
-        )
-
-        power_mw = (
-            mass_rate_to_use_kg_per_hour
-            * polytropic_enthalpy_change_to_use_joule_per_kg
-            / UnitConstants.SECONDS_PER_HOUR
-            * UnitConstants.WATT_TO_MEGAWATT
-        )
-        # Set power to nan for points where compressor capacity is exceeded
-        if exceeds_capacity:
-            power_mw = np.nan
-
-        polytropic_enthalpy_change_kilo_joule_per_kg = polytropic_enthalpy_change_joule_per_kg * UnitConstants.TO_KILO
-
-        if pressure_is_choked and rate_has_recirc:
-            chart_area_flag = ChartAreaFlag.BELOW_MINIMUM_SPEED_AND_BELOW_MINIMUM_FLOW_RATE
-        elif pressure_is_choked and rate_exceeds_maximum:
-            chart_area_flag = ChartAreaFlag.BELOW_MINIMUM_SPEED_AND_ABOVE_MAXIMUM_FLOW_RATE
-        elif rate_has_recirc:
-            chart_area_flag = ChartAreaFlag.BELOW_MINIMUM_FLOW_RATE
-        elif rate_exceeds_maximum:
-            chart_area_flag = ChartAreaFlag.ABOVE_MAXIMUM_FLOW_RATE
-        elif pressure_is_choked:
-            chart_area_flag = ChartAreaFlag.BELOW_MINIMUM_SPEED
-        elif head_exceeds_maximum:
-            chart_area_flag = ChartAreaFlag.ABOVE_MAXIMUM_SPEED
-        else:
-            chart_area_flag = ChartAreaFlag.INTERNAL_POINT
-
-        return CompressorTrainStageResultSingleTimeStep(
-            inlet_stream=inlet_stream,
-            outlet_stream=outlet_stream,
-            inlet_stream_including_asv=FluidStream(
-                thermo_system=inlet_stream.thermo_system,
-                mass_rate_kg_per_h=mass_rate_to_use_kg_per_hour,
-            ),
-            outlet_stream_including_asv=FluidStream(
-                thermo_system=outlet_stream.thermo_system,
-                mass_rate_kg_per_h=mass_rate_to_use_kg_per_hour,
-            ),
-            power_megawatt=power_mw,  # type: ignore[arg-type]
-            chart_area_flag=chart_area_flag,
-            polytropic_enthalpy_change_kJ_per_kg=polytropic_enthalpy_change_to_use_joule_per_kg / 1000,  # type: ignore[arg-type]
-            polytropic_enthalpy_change_before_choke_kJ_per_kg=polytropic_enthalpy_change_kilo_joule_per_kg,  # type: ignore[arg-type]
-            polytropic_head_kJ_per_kg=(polytropic_enthalpy_change_to_use_joule_per_kg * polytropic_efficiency) / 1000,  # type: ignore[arg-type]
-            polytropic_efficiency=polytropic_efficiency,  # type: ignore[arg-type]
-            rate_has_recirculation=rate_has_recirc,
-            rate_exceeds_maximum=rate_exceeds_maximum,
-            pressure_is_choked=pressure_is_choked,
-            head_exceeds_maximum=head_exceeds_maximum,
-            # Assuming choking and ASV. Valid points are to the left and below the compressor chart.
-            point_is_valid=~np.isnan(power_mw),  # type: ignore[arg-type] # power_mw is set to np.NaN if invalid step.
-        )
-
 
 class CompressorTrainSimplifiedKnownStages(CompressorTrainSimplified):
     def __init__(
@@ -321,19 +194,17 @@ class CompressorTrainSimplifiedKnownStages(CompressorTrainSimplified):
         fluid_factory: FluidFactoryInterface,
         energy_usage_adjustment_constant: float,
         energy_usage_adjustment_factor: float,
-        stages: list[CompressorStage],
+        stages: list[CompressorTrainStage],
         calculate_max_rate: bool = False,
         maximum_power: float | None = None,
     ):
         """See CompressorTrainSimplified for explanation of a compressor train."""
         logger.debug(f"Creating CompressorTrainSimplifiedKnownStages with n_stages: {len(stages)}")
-        stages_mapped = [map_compressor_train_stage_to_domain(stage_dto) for stage_dto in stages]
         super().__init__(
             fluid_factory=fluid_factory,
             energy_usage_adjustment_constant=energy_usage_adjustment_constant,
             energy_usage_adjustment_factor=energy_usage_adjustment_factor,
-            stages=stages_mapped,
-            typ=EnergyModelType.COMPRESSOR_TRAIN_SIMPLIFIED_WITH_KNOWN_STAGES,
+            stages=stages,
             maximum_power=maximum_power,
             pressure_control=None,  # Not relevant for simplified trains.
             calculate_max_rate=calculate_max_rate,
@@ -401,7 +272,7 @@ class CompressorTrainSimplifiedKnownStages(CompressorTrainSimplified):
                     temperature_kelvin=inlet_temperatures_kelvin_to_use[stage_number],
                     mass_rate_kg_per_h=1,
                 ),
-                compressor_chart=chart,  # type: ignore[arg-type]
+                compressor_chart=chart,
                 pressure_ratio=pressure_ratios_per_stage,  # type: ignore[arg-type]
             )
             for stage_number, chart in enumerate(compressor_charts)
@@ -430,7 +301,7 @@ class CompressorTrainSimplifiedKnownStages(CompressorTrainSimplified):
     def calculate_maximum_rate_for_stage(
         pressure_ratio: float,
         inlet_stream: FluidStream,
-        compressor_chart: VariableSpeedCompressorChart,
+        compressor_chart: CompressorChart,
     ) -> float:
         """Calculate the maximum standard rate for a single set of inputs."""
         outlet_pressure = inlet_stream.pressure_bara * pressure_ratio
@@ -532,7 +403,7 @@ class CompressorTrainSimplifiedUnknownStages(CompressorTrainSimplified):
         fluid_factory: FluidFactoryInterface,
         energy_usage_adjustment_constant: float,
         energy_usage_adjustment_factor: float,
-        stage: CompressorStage,
+        stage: CompressorTrainStage,
         maximum_pressure_ratio_per_stage: float,
         calculate_max_rate: bool = False,
         maximum_power: float | None = None,
@@ -544,7 +415,6 @@ class CompressorTrainSimplifiedUnknownStages(CompressorTrainSimplified):
             energy_usage_adjustment_constant=energy_usage_adjustment_constant,
             energy_usage_adjustment_factor=energy_usage_adjustment_factor,
             stages=[],  # Stages are not defined yet
-            typ=EnergyModelType.COMPRESSOR_TRAIN_SIMPLIFIED_WITH_UNKNOWN_STAGES,
             maximum_power=maximum_power,
             pressure_control=None,  # Not relevant for simplified trains.
             calculate_max_rate=calculate_max_rate,
@@ -569,7 +439,7 @@ class CompressorTrainSimplifiedUnknownStages(CompressorTrainSimplified):
             compressor_maximum_pressure_ratio=self.maximum_pressure_ratio_per_stage,
         )
 
-        return [map_compressor_train_stage_to_domain(self.stage) for _ in range(number_of_compressors)]
+        return [self.stage for _ in range(number_of_compressors)]
 
     @staticmethod
     def _calculate_number_of_compressors_needed(
