@@ -9,14 +9,13 @@ from libecalc.common.time_utils import Frequency, Period, Periods
 from libecalc.common.units import Unit
 from libecalc.common.utils.rates import TimeSeriesFloat, TimeSeriesStreamDayRate
 from libecalc.common.variables import ExpressionEvaluator, VariablesMap
-from libecalc.core.result import EcalcModelResult
+from libecalc.core.result import ComponentResult, EcalcModelResult
 from libecalc.core.result.emission import EmissionResult
 from libecalc.domain.energy import ComponentEnergyContext, Emitter, EnergyComponent, EnergyModel
 from libecalc.domain.infrastructure.energy_components.asset.asset import Asset
 from libecalc.domain.installation import (
     Installation,
 )
-from libecalc.domain.resource import Resources
 from libecalc.dto import ResultOptions
 from libecalc.dto.component_graph import ComponentGraph
 from libecalc.presentation.yaml.domain.category_service import CategoryService
@@ -60,13 +59,16 @@ class Context(ComponentEnergyContext):
         self._consumer_results = consumer_results
         self._component_id = component_id
 
-    def get_power_requirement(self) -> TimeSeriesFloat | None:
-        consumer_power_usage = [
-            self._consumer_results[consumer.id].component_result.power
+    def _get_consumers_of_current(self) -> list[ComponentResult]:
+        return [
+            self._consumer_results[consumer.id].component_result
             for consumer in self._energy_model.get_consumers(self._component_id)
-            if self._consumer_results[consumer.id].component_result.power is not None
         ]
 
+    def get_power_requirement(self) -> TimeSeriesFloat | None:
+        consumer_results = self._get_consumers_of_current()
+        consumer_power_usage = [consumer.power for consumer in consumer_results if consumer.power is not None]
+
         if len(consumer_power_usage) < 1:
             return None
 
@@ -129,8 +131,8 @@ class YamlModel(EnergyModel):
     def get_expression_evaluator(self) -> ExpressionEvaluator:
         return self.variables
 
-    def _get_reference_service(self, facility_resources: Resources) -> ReferenceService:
-        return YamlReferenceService(configuration=self._configuration, resources=facility_resources)
+    def _get_reference_service(self) -> ReferenceService:
+        return YamlReferenceService(configuration=self._configuration)
 
     @property
     def period(self) -> Period:
@@ -264,19 +266,21 @@ class YamlModel(EnergyModel):
                 periods=self._get_periods(time_series_collections.get_time_vector()),
             )
 
-            reference_service = self._get_reference_service(facility_resources=facility_resources)
+            reference_service = self._get_reference_service()
 
             # Is validated, first step, must be set before calling get_graph
             self._is_validated = True
             # Validate and create the graph used for evaluating the energy model
             model_mapper = EcalcModelMapper(
+                resources=facility_resources,
                 references=reference_service,
                 target_period=self.period,
                 expression_evaluator=self._variables,
                 mapping_context=self._mapping_context,
+                configuration=self._configuration,
             )
 
-            self._input = model_mapper.from_yaml_to_domain(configuration=self._configuration)
+            self._input = model_mapper.from_yaml_to_domain()
             self._graph = self._input.get_graph()
             return self
         except InvalidVariablesException as e:
